
import { openThem } from "../contents";


export const goTo = (el: HTMLElement): void => {
    const elementRect = el.getBoundingClientRect();
    const elementTop = elementRect.top + window.pageYOffset; // Absolute position from the top of the document
    const viewportHeight = window.innerHeight;

    // Calculate the scroll position so the top of the element is centered in the viewport
    const middlePosition = elementTop - (viewportHeight / 2 - el.offsetHeight / 2);

    window.scrollTo({
        top: middlePosition,
        behavior: 'smooth'
    });
};
interface ScrollLinkProps {
    targetId: string;
    label: string;

}

interface ScrollLinkWithChildProps {
    targetId: string;
    children: React.ReactNode;
}
interface OpenScrollLinkWithChildProps {
    targetId: string;
    children: React.ReactNode;
    openThis:  string;   /*(_event: MouseEvent<HTMLElement, MouseEvent>) => void; */
}
interface SupScrollLinkProps {
    label: string;
}



export const ScrollLink: React.FC<ScrollLinkProps> = ({ targetId, label }) => {
    const handleClick = (event: React.MouseEvent<HTMLAnchorElement, MouseEvent>) => {
        event.preventDefault(); // Prevent default anchor behavior
        const targetElement = document.getElementById(targetId);
        if (targetElement) {
            goTo(targetElement);
        }
    };

    return (
        <a href={`#${targetId}`} onClick={handleClick}>
            {label}
        </a>
    );
};
export const ScrollLinkSidebar: React.FC<OpenScrollLinkWithChildProps> = ({ targetId, children, openThis}) => {
    const handleClick = () => {
        const targetElement = document.getElementById(targetId);
        if (targetElement) {
            goTo(targetElement);
        }
        openThem({it: openThis}); 
    };
    
    return (
        <a onClick={handleClick}>
            {children}
        </a>
    );
};
export const ScrollLinkWithChild: React.FC<ScrollLinkWithChildProps> = ({ targetId, children }) => {
    const handleClick = () => {
        const targetElement = document.getElementById(targetId);
        if (targetElement) {
            goTo(targetElement);
        }
    };

    return (
        <a onClick={handleClick}>
            {children}
        </a>
    );
};

export const SupScrollLink : React.FC<SupScrollLinkProps> = ({label }) => {
    let targetId = "desc-" + label
    const handleClick = () => {
        const targetElement = document.getElementById(targetId);
        if (targetElement) {
            goTo(targetElement);
        }
    };

    return (
       <sup><a onClick={handleClick}>
            {label}
        </a>
        </sup> 
    );
};
/* 
export const goToTextsAndOpenCollapsible = ({collapseId, path}: {collapseId: string, path: string}) => {
    const navigate = useNavigate();
    navigate(`${path}${collapseId}`);
};
export const goToPagesAndOpenTab = (tabId: string, path: string) => {
    const navigate = useNavigate();
    navigate(`${path}${tabId}`);
}; */